use Test::More tests => 3;

use FindBin;
use lib "$FindBin::Bin/../lib";
use strict;
use warnings;

require_ok( 'Digest::MD5' );
use_ok 'Hash::MD5';
use_ok 'Digest::MD5';

#ok($got eq $expected, $test_name);