use Test::More tests => 2;

use FindBin;
use lib "$FindBin::Bin/../lib";
use strict;
use warnings;
use Hash::MD5;

my $sum1 = Hash::MD5::sum_array( ["This", { string => "This is a test string.", number => 'This is a another string.'}, "a", "test", "string."] );
my $sum2 = Hash::MD5::sum_array( ["This", { number => 'This is a another string.', string => "This is a test string."}, "a", "test", "string."] );
ok(('a7997254689730ef5c665878b81192f5' eq $sum1) == 1, 'test array with numbers');
ok(($sum1 eq $sum2) == 1, 'test compare array with numbers');